@@ -6,10 +6,10 @@ test_that("add_lkm works", {
 
 test_that("add_lkm works", {
   expect_equal(add_lkm(matrix(1, ncol = 10))$V1[1],
-               1)
+               units::set_units(1, "km"))
 })
 
 test_that("add_lkm works", {
   expect_equal(add_lkm(as.data.frame(matrix(1, ncol = 10)))$V1[1],
-  1)
+               units::set_units(1, "km"))
 })
